Index: uspace/lib/net/generic/generic.c
===================================================================
--- uspace/lib/net/generic/generic.c	(revision 7bf123871317a0c9460ed9b58b81cba56a85baae)
+++ uspace/lib/net/generic/generic.c	(revision 1affcdf3220abde47fe1219335c44e6763d27fd6)
@@ -37,4 +37,5 @@
 #include <generic.h>
 #include <async.h>
+#include <async_obsolete.h>
 #include <ipc/services.h>
 #include <net/device.h>
@@ -56,5 +57,5 @@
     int state, services_t target)
 {
-	async_msg_3(phone, (sysarg_t) message, (sysarg_t) device_id,
+	async_obsolete_msg_3(phone, (sysarg_t) message, (sysarg_t) device_id,
 	    (sysarg_t) state, target);
 	
@@ -78,5 +79,5 @@
     int arg2, services_t service)
 {
-	return (int) async_req_3_0(phone, (sysarg_t) message,
+	return (int) async_obsolete_req_3_0(phone, (sysarg_t) message,
 	    (sysarg_t) device_id, (sysarg_t) arg2, (sysarg_t) service);
 }
@@ -107,5 +108,5 @@
 
 	/* Request the address */
-	message_id = async_send_1(phone, (sysarg_t) message,
+	message_id = async_obsolete_send_1(phone, (sysarg_t) message,
 	    (sysarg_t) device_id, NULL);
 	string = measured_strings_return(phone, address, data, 1);
@@ -145,5 +146,5 @@
 	sysarg_t suffix;
 	
-	sysarg_t result = async_req_1_4(phone, (sysarg_t) message,
+	sysarg_t result = async_obsolete_req_1_4(phone, (sysarg_t) message,
 	    (sysarg_t) device_id, &addr_len, &prefix, &content, &suffix);
 	
@@ -172,8 +173,8 @@
 {
 	if (error) {
-		async_msg_4(phone, (sysarg_t) message, (sysarg_t) device_id,
+		async_obsolete_msg_4(phone, (sysarg_t) message, (sysarg_t) device_id,
 		    (sysarg_t) packet_id, (sysarg_t) target, (sysarg_t) error);
 	} else {
-		async_msg_3(phone, (sysarg_t) message, (sysarg_t) device_id,
+		async_obsolete_msg_3(phone, (sysarg_t) message, (sysarg_t) device_id,
 		    (sysarg_t) packet_id, (sysarg_t) target);
 	}
@@ -198,8 +199,8 @@
 {
 	if (error) {
-		async_msg_4(phone, (sysarg_t) message, (sysarg_t) device_id,
+		async_obsolete_msg_4(phone, (sysarg_t) message, (sysarg_t) device_id,
 		    (sysarg_t) packet_id, (sysarg_t) sender, (sysarg_t) error);
 	} else {
-		async_msg_3(phone, (sysarg_t) message, (sysarg_t) device_id,
+		async_obsolete_msg_3(phone, (sysarg_t) message, (sysarg_t) device_id,
 		    (sysarg_t) packet_id, (sysarg_t) sender);
 	}
@@ -243,5 +244,5 @@
 
 	/* Request the translation */
-	message_id = async_send_3(phone, (sysarg_t) message,
+	message_id = async_obsolete_send_3(phone, (sysarg_t) message,
 	    (sysarg_t) device_id, (sysarg_t) count, (sysarg_t) service, NULL);
 	measured_strings_send(phone, configuration, count);
Index: uspace/lib/net/il/arp_remote.c
===================================================================
--- uspace/lib/net/il/arp_remote.c	(revision 7bf123871317a0c9460ed9b58b81cba56a85baae)
+++ uspace/lib/net/il/arp_remote.c	(revision 1affcdf3220abde47fe1219335c44e6763d27fd6)
@@ -40,4 +40,5 @@
 
 #include <async.h>
+#include <async_obsolete.h>
 #include <errno.h>
 #include <ipc/services.h>
@@ -68,5 +69,5 @@
 int arp_clean_cache_req(int arp_phone)
 {
-	return (int) async_req_0_0(arp_phone, NET_ARP_CLEAN_CACHE);
+	return (int) async_obsolete_req_0_0(arp_phone, NET_ARP_CLEAN_CACHE);
 }
 
@@ -87,5 +88,5 @@
 	sysarg_t result;
 
-	message_id = async_send_2(arp_phone, NET_ARP_CLEAR_ADDRESS,
+	message_id = async_obsolete_send_2(arp_phone, NET_ARP_CLEAR_ADDRESS,
 	    (sysarg_t) device_id, protocol, NULL);
 	measured_strings_send(arp_phone, address, 1);
@@ -104,5 +105,5 @@
 int arp_clear_device_req(int arp_phone, device_id_t device_id)
 {
-	return (int) async_req_1_0(arp_phone, NET_ARP_CLEAR_DEVICE,
+	return (int) async_obsolete_req_1_0(arp_phone, NET_ARP_CLEAR_DEVICE,
 	    (sysarg_t) device_id);
 }
@@ -137,5 +138,5 @@
 	sysarg_t result;
 
-	message_id = async_send_3(arp_phone, NET_ARP_DEVICE,
+	message_id = async_obsolete_send_3(arp_phone, NET_ARP_DEVICE,
 	    (sysarg_t) device_id, protocol, netif, NULL);
 	measured_strings_send(arp_phone, address, 1);
Index: uspace/lib/net/il/il_skel.c
===================================================================
--- uspace/lib/net/il/il_skel.c	(revision 7bf123871317a0c9460ed9b58b81cba56a85baae)
+++ uspace/lib/net/il/il_skel.c	(revision 1affcdf3220abde47fe1219335c44e6763d27fd6)
@@ -42,4 +42,7 @@
 #include <net/modules.h>
 
+// FIXME: remove this header
+#include <kernel/ipc/ipc_methods.h>
+
 /** Default thread for new connections.
  *
@@ -75,6 +78,5 @@
 		 * result.
 		 */
-		if ((IPC_GET_IMETHOD(call) == IPC_M_PHONE_HUNGUP) ||
-		    (res == EHANGUP))
+		if ((!IPC_GET_IMETHOD(call)) || (res == EHANGUP))
 			return;
 		
Index: uspace/lib/net/il/ip_remote.c
===================================================================
--- uspace/lib/net/il/ip_remote.c	(revision 7bf123871317a0c9460ed9b58b81cba56a85baae)
+++ uspace/lib/net/il/ip_remote.c	(revision 1affcdf3220abde47fe1219335c44e6763d27fd6)
@@ -44,5 +44,5 @@
 #include <packet_client.h>
 #include <generic.h>
-
+#include <async_obsolete.h>
 #include <ipc/services.h>
 #include <ipc/il.h>
@@ -66,5 +66,5 @@
     in_addr_t address, in_addr_t netmask, in_addr_t gateway)
 {
-	return (int) async_req_4_0(ip_phone, NET_IP_ADD_ROUTE,
+	return (int) async_obsolete_req_4_0(ip_phone, NET_IP_ADD_ROUTE,
 	    (sysarg_t) device_id, (sysarg_t) gateway.s_addr,
 	    (sysarg_t) address.s_addr, (sysarg_t) netmask.s_addr);
@@ -150,13 +150,13 @@
 	
 	ipc_call_t answer;
-	aid_t message_id = async_send_1(ip_phone, NET_IP_GET_ROUTE,
+	aid_t message_id = async_obsolete_send_1(ip_phone, NET_IP_GET_ROUTE,
 	    (sysarg_t) protocol, &answer);
 	
-	if ((async_data_write_start(ip_phone, destination, addrlen) == EOK) &&
-	    (async_data_read_start(ip_phone, headerlen,
+	if ((async_obsolete_data_write_start(ip_phone, destination, addrlen) == EOK) &&
+	    (async_obsolete_data_read_start(ip_phone, headerlen,
 	    sizeof(*headerlen)) == EOK) && (*headerlen > 0)) {
 		*header = malloc(*headerlen);
 		if (*header) {
-			if (async_data_read_start(ip_phone, *header,
+			if (async_obsolete_data_read_start(ip_phone, *header,
 			    *headerlen) != EOK)
 				free(*header);
@@ -243,5 +243,5 @@
     in_addr_t gateway)
 {
-	return (int) async_req_2_0(ip_phone, NET_IP_SET_GATEWAY,
+	return (int) async_obsolete_req_2_0(ip_phone, NET_IP_SET_GATEWAY,
 	    (sysarg_t) device_id, (sysarg_t) gateway.s_addr);
 }
Index: uspace/lib/net/netif/netif_remote.c
===================================================================
--- uspace/lib/net/netif/netif_remote.c	(revision 7bf123871317a0c9460ed9b58b81cba56a85baae)
+++ uspace/lib/net/netif/netif_remote.c	(revision 1affcdf3220abde47fe1219335c44e6763d27fd6)
@@ -38,5 +38,5 @@
 #include <packet_client.h>
 #include <generic.h>
-
+#include <async_obsolete.h>
 #include <ipc/services.h>
 #include <ipc/netif.h>
@@ -82,5 +82,5 @@
 int netif_probe_req(int netif_phone, device_id_t device_id, int irq, void *io)
 {
-	return async_req_3_0(netif_phone, NET_NETIF_PROBE, device_id, irq,
+	return async_obsolete_req_3_0(netif_phone, NET_NETIF_PROBE, device_id, irq,
 	    (sysarg_t) io);
 }
@@ -119,5 +119,5 @@
 int netif_start_req(int netif_phone, device_id_t device_id)
 {
-	return async_req_1_0(netif_phone, NET_NETIF_START, device_id);
+	return async_obsolete_req_1_0(netif_phone, NET_NETIF_START, device_id);
 }
 
@@ -136,5 +136,5 @@
 int netif_stop_req(int netif_phone, device_id_t device_id)
 {
-	return async_req_1_0(netif_phone, NET_NETIF_STOP, device_id);
+	return async_obsolete_req_1_0(netif_phone, NET_NETIF_STOP, device_id);
 }
 
@@ -154,7 +154,7 @@
 		return EBADMEM;
 	
-	aid_t message_id = async_send_1(netif_phone, NET_NETIF_STATS,
+	aid_t message_id = async_obsolete_send_1(netif_phone, NET_NETIF_STATS,
 	    (sysarg_t) device_id, NULL);
-	async_data_read_start(netif_phone, stats, sizeof(*stats));
+	async_obsolete_data_read_start(netif_phone, stats, sizeof(*stats));
 	
 	sysarg_t result;
Index: uspace/lib/net/netif/netif_skel.c
===================================================================
--- uspace/lib/net/netif/netif_skel.c	(revision 7bf123871317a0c9460ed9b58b81cba56a85baae)
+++ uspace/lib/net/netif/netif_skel.c	(revision 1affcdf3220abde47fe1219335c44e6763d27fd6)
@@ -54,4 +54,7 @@
 #include <nil_remote.h>
 
+// FIXME: remove this header
+#include <kernel/ipc/ipc_methods.h>
+
 DEVICE_MAP_IMPLEMENT(netif_device_map, netif_device_t);
 
@@ -288,8 +291,8 @@
 	*count = 0;
 	
+	if (!IPC_GET_IMETHOD(*call))
+		return EOK;
+	
 	switch (IPC_GET_IMETHOD(*call)) {
-	case IPC_M_PHONE_HUNGUP:
-		return EOK;
-	
 	case NET_NETIF_PROBE:
 		return netif_probe_req_local(0, IPC_GET_DEVICE(*call),
@@ -385,6 +388,5 @@
 		
 		/* End if said to either by the message or the processing result */
-		if ((IPC_GET_IMETHOD(call) == IPC_M_PHONE_HUNGUP) ||
-		    (res == EHANGUP))
+		if ((!IPC_GET_IMETHOD(call)) || (res == EHANGUP))
 			return;
 		
Index: uspace/lib/net/nil/nil_skel.c
===================================================================
--- uspace/lib/net/nil/nil_skel.c	(revision 7bf123871317a0c9460ed9b58b81cba56a85baae)
+++ uspace/lib/net/nil/nil_skel.c	(revision 1affcdf3220abde47fe1219335c44e6763d27fd6)
@@ -42,4 +42,7 @@
 #include <net/modules.h>
 
+// FIXME: remove this header
+#include <kernel/ipc/ipc_methods.h>
+
 /** Default thread for new connections.
  *
@@ -75,6 +78,5 @@
 		 * result.
 		 */
-		if ((IPC_GET_IMETHOD(call) == IPC_M_PHONE_HUNGUP) ||
-		    (res == EHANGUP))
+		if ((!IPC_GET_IMETHOD(call)) || (res == EHANGUP))
 			return;
 		
Index: uspace/lib/net/tl/icmp_remote.c
===================================================================
--- uspace/lib/net/tl/icmp_remote.c	(revision 7bf123871317a0c9460ed9b58b81cba56a85baae)
+++ uspace/lib/net/tl/icmp_remote.c	(revision 1affcdf3220abde47fe1219335c44e6763d27fd6)
@@ -41,4 +41,5 @@
 
 #include <async.h>
+#include <async_obsolete.h>
 #include <errno.h>
 #include <ipc/services.h>
@@ -64,5 +65,5 @@
     icmp_param_t mtu, packet_t *packet)
 {
-	async_msg_3(icmp_phone, NET_ICMP_DEST_UNREACH, (sysarg_t) code,
+	async_obsolete_msg_3(icmp_phone, NET_ICMP_DEST_UNREACH, (sysarg_t) code,
 	    (sysarg_t) packet_get_id(packet), (sysarg_t) mtu);
 	return EOK;
@@ -83,5 +84,5 @@
 int icmp_source_quench_msg(int icmp_phone, packet_t *packet)
 {
-	async_msg_2(icmp_phone, NET_ICMP_SOURCE_QUENCH, 0,
+	async_obsolete_msg_2(icmp_phone, NET_ICMP_SOURCE_QUENCH, 0,
 	    (sysarg_t) packet_get_id(packet));
 	return EOK;
@@ -103,5 +104,5 @@
 int icmp_time_exceeded_msg(int icmp_phone, icmp_code_t code, packet_t *packet)
 {
-	async_msg_2(icmp_phone, NET_ICMP_TIME_EXCEEDED, (sysarg_t) code,
+	async_obsolete_msg_2(icmp_phone, NET_ICMP_TIME_EXCEEDED, (sysarg_t) code,
 	    (sysarg_t) packet_get_id(packet));
 	return EOK;
@@ -125,5 +126,5 @@
     icmp_param_t pointer, packet_t *packet)
 {
-	async_msg_3(icmp_phone, NET_ICMP_PARAMETERPROB, (sysarg_t) code,
+	async_obsolete_msg_3(icmp_phone, NET_ICMP_PARAMETERPROB, (sysarg_t) code,
 	    (sysarg_t) packet_get_id(packet), (sysarg_t) pointer);
 	return EOK;
Index: uspace/lib/net/tl/tl_skel.c
===================================================================
--- uspace/lib/net/tl/tl_skel.c	(revision 7bf123871317a0c9460ed9b58b81cba56a85baae)
+++ uspace/lib/net/tl/tl_skel.c	(revision 1affcdf3220abde47fe1219335c44e6763d27fd6)
@@ -42,4 +42,7 @@
 #include <net/modules.h>
 
+// FIXME: remove this header
+#include <kernel/ipc/ipc_methods.h>
+
 /** Default thread for new connections.
  *
@@ -77,6 +80,5 @@
 		 * result.
 		 */
-		if ((IPC_GET_IMETHOD(call) == IPC_M_PHONE_HUNGUP) ||
-		    (res == EHANGUP))
+		if ((!IPC_GET_IMETHOD(call)) || (res == EHANGUP))
 			return;
 		

Index: uspace/lib/net/generic/packet_remote.c
===================================================================
--- uspace/lib/net/generic/packet_remote.c	(revision 7bf123871317a0c9460ed9b58b81cba56a85baae)
+++ uspace/lib/net/generic/packet_remote.c	(revision 1affcdf3220abde47fe1219335c44e6763d27fd6)
@@ -37,4 +37,5 @@
 
 #include <async.h>
+#include <async_obsolete.h>
 #include <errno.h>
 #include <ipc/packet.h>
@@ -59,5 +60,5 @@
  * @return EOK on success.
  * @return Other error codes as defined for the pm_add() function.
  * @return Other error codes as defined for the async_share_in_start() function.
  *
  */
@@ -69,8 +70,8 @@
 	int rc;
 	
-	message = async_send_1(phone, NET_PACKET_GET, packet_id, &answer);
+	message = async_obsolete_send_1(phone, NET_PACKET_GET, packet_id, &answer);
 
 	*packet = (packet_t *) as_get_mappable_page(size);
-	rc = async_share_in_start_0_0(phone, *packet, size);
+	rc = async_obsolete_share_in_start_0_0(phone, *packet, size);
 	if (rc != EOK) {
 		munmap(*packet, size);
@@ -117,5 +118,5 @@
 		sysarg_t size;
 		
-		rc = async_req_1_1(phone, NET_PACKET_GET_SIZE, packet_id,
+		rc = async_obsolete_req_1_1(phone, NET_PACKET_GET_SIZE, packet_id,
 		    &size);
 		if (rc != EOK)
@@ -154,5 +155,5 @@
 	int rc;
 	
-	rc = async_req_4_2(phone, NET_PACKET_CREATE_4, max_content, addr_len,
+	rc = async_obsolete_req_4_2(phone, NET_PACKET_CREATE_4, max_content, addr_len,
 	    max_prefix, max_suffix, &packet_id, &size);
 	if (rc != EOK)
@@ -185,5 +186,5 @@
 	int rc;
 	
-	rc = async_req_1_2(phone, NET_PACKET_CREATE_1, content, &packet_id,
+	rc = async_obsolete_req_1_2(phone, NET_PACKET_CREATE_1, content, &packet_id,
 	    &size);
 	if (rc != EOK)
@@ -212,5 +213,5 @@
 void pq_release_remote(int phone, packet_id_t packet_id)
 {
-	async_msg_1(phone, NET_PACKET_RELEASE, packet_id);
+	async_obsolete_msg_1(phone, NET_PACKET_RELEASE, packet_id);
 }
 
@@ -59,5 +60,5 @@
  * @return EOK on success.
  * @return Other error codes as defined for the pm_add() function.
- * @return Other error codes as defined for the async_share_in_start() function.
+ * @return Other error codes as defined for the async_obsolete_share_in_start() function.
  *
  */